@@ -226,7 +226,7 @@ bool KArchive::addLocalFile(const QString &fileName, const QString &destName)
         int len = readlink(encodedFileName.data(), s.data(), s.size() - 1);
         if (len >= 0) {
             s[len] = '\0';
-            symLinkTarget = QFile::decodeName(s);
+            symLinkTarget = QFile::decodeName(s.constData());
         }
 #endif
         if (symLinkTarget.isEmpty()) { // Mac or Windows
@@ -410,7 +410,7 @@ KArchiveDirectory *KArchive::rootDir()
         QString username = ::getCurrentUserName();
         QString groupname = ::getCurrentGroupName();
 
-        d->rootDir = new KArchiveDirectory(this, QLatin1String("/"), (int)(0777 + S_IFDIR), QDateTime(), username, groupname, QString());
+        d->rootDir = new KArchiveDirectory(this, QStringLiteral("/"), (int)(0777 + S_IFDIR), QDateTime(), username, groupname, QString());
     }
     return d->rootDir;
 }
@@ -864,8 +864,8 @@ bool KArchiveDirectory::copyTo(const QString &dest, bool recursiveCopy) const
                 QString linkName = curDirName + QLatin1Char('/') + curEntry->name();
                 // To create a valid link on Windows, linkName must have a .lnk file extension.
 #ifdef Q_OS_WIN
-                if (!linkName.endsWith(QStringLiteral(".lnk"))) {
-                    linkName += QStringLiteral(".lnk");
+                if (!linkName.endsWith(QLatin1String(".lnk"))) {
+                    linkName += QLatin1String(".lnk");
                 }
 #endif
                 QFile symLinkTarget(curEntry->symLinkTarget());
